Skip to contents

Delete a signature from the signatures table of the database

Usage

deleteSignature(conn_handler = NULL, signature_id = NULL, verbose = TRUE)

Arguments

conn_handler

An R object obtained from SigRepo::newConnhandler() (required)

signature_id

Database ID of signature to be removed from the database (required)

verbose

Logical; whether or not to print the diagnostic messages. Default is TRUE.

Examples


if (FALSE) { # \dontrun{

# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
  dbname = "sigrepo", 
  host = "sigrepo.org", 
  port = 3306, 
  user = "your_username", 
  password = "your_password"
)

# Delete signature from database
SigRepo::deleteSignature(
  conn_handler = conn_handler,
  signature_id = 56,
  verbose = TRUE
)

} # }