Skip to contents

Delete a list of signatures from a collection in the database

Usage

removeSignatureFromCollection(
  conn_handler = NULL,
  collection_id,
  signature_id,
  verbose = TRUE
)

Arguments

conn_handler

An R object obtained from SigRepo::newConnhandler() (required)

collection_id

Database ID of the collection (required)

signature_id

A list of signature database IDs to be removed from a collection in the database (required)

verbose

Logical; whether or not to print the diagnostic messages. Default is TRUE.

Examples


if (FALSE) { # \dontrun{

# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
  dbname = "sigrepo", 
  host = "sigrepo.org", 
  port = 3306, 
  user = "your_username", 
  password = "your_password"
)

# Delete a list of signatures from a collection
SigRepo::removeSignatureFromCollection(
  conn_handler = conn_handler, 
  collection_id = 60,
  signature_id = c(59, 70),
  verbose = TRUE
)

} # }