Skip to contents

Search for a list of collection in the database

Usage

searchCollection(
  conn_handler = NULL,
  collection_id = NULL,
  collection_name = NULL,
  signature_name = NULL,
  signature_id = NULL,
  user_name = NULL,
  verbose = TRUE
)

Arguments

conn_handler

An R object obtained from SigRepo::newConnhandler() (required)

collection_id

Database ID of collection to be looked up by.

collection_name

Name of collection to be looked up by.

signature_name

Signature name of the signatures to be looked up by.

signature_id

Database ID of the signatures to be looked up by.

user_name

Name of users that the collection belongs to.

verbose

Logical; whether or not to print the diagnostic messages. Defaults to 'TRUE'.

Examples


if (FALSE) { # \dontrun{

# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
  dbname = "sigrepo", 
  host = "sigrepo.org", 
  port = 3306, 
  user = "your_username", 
  password = "your_password"
)

# Delete a list of organisms from database
SigRepo::searchCollection(
  conn_handler = conn_handler, 
  collection_name = "test_collection", 
  collection_id = "67"
)

} # }