Skip to contents

Search for an organism in the database, can handle a singular organism or list

Usage

searchOrganism(conn_handler = NULL, organism = NULL, verbose = TRUE)

Arguments

conn_handler

An R object obtained from SigRepo::newConnhandler() (required)

organism

an organism, or list of organisms to search by. Default is NULL which will return all of the organisms in the database.

verbose

Logical; whether or not to print the diagnostic messages. Defaults to 'TRUE'.

Examples


if (FALSE) { # \dontrun{

# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
  dbname = "sigrepo", 
  host = "sigrepo.org", 
  port = 3306, 
  user = "your_username", 
  password = "your_password"
)

# Search for a list of organims in the database 
SigRepo::searchOrganism(
  conn_handler = conn_handler,
  organism = "Mus musculus",
  verbose = TRUE
)

} # }