Skip to contents

Search for a phenotype in the database

Usage

searchPhenotype(conn_handler = NULL, phenotype = NULL, verbose = TRUE)

Arguments

conn_handler

An R object obtained from SigRepo::newConnhandler() (required)

phenotype

A phenotype, or a list of phenotypes to search by. Default is NULL which will return all of the phenotypes in the database

verbose

Logical; whether or not to print the diagnostic messages. Defaults to 'TRUE'.

Examples


if (FALSE) { # \dontrun{

# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
  dbname = "sigrepo", 
  host = "sigrepo.org", 
  port = 3306, 
  user = "your_username", 
  password = "your_password"
)

# Search for a list of phenotypes in the database
SigRepo::searchPhenotype(
  conn_handler = conn_handler,
  phenotype = "test_phenotype",
  verbose = TRUE
)

} # }