Add a list of signatures to a collection in the database
Arguments
- conn_handler
An R object obtained from SigRepo::newConnhandler() (required)
- collection_id
Database ID of the OmicSignature Collection (required)
- signature_id
A single signature database ID, or a list, to be added to a collection in the database (required)
- verbose
Logical; whether to print diagnostic messages. Defaults to 'TRUE'
Examples
if (FALSE) { # \dontrun{
# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
dbname = "sigrepo",
host = "sigrepo.org",
port = 3306,
user = "your_username",
password = "your_password"
)
# Add a list of signatures to a collection
SigRepo::addSignatureToCollection(
conn_handler = conn_handler,
collection_id = 1,
signature_id = c(1, 67, 80, 5),
verbose = FALSE
)
} # }