Compare significant feature overlap between two signatures
Source:R/compareSignature.R
compareSignatureFeatures.RdReturns the number of significant features unique to signature A,
unique to signature B, and shared by both signatures. Significant features are
read from the signature table of each OmicSignature object retrieved
from the SigRepo database. If you already have OmicSignature objects, pass
them with omic_signature_a and omic_signature_b.
Usage
compareSignatureFeatures(
conn_handler = NULL,
signature_id_a = NULL,
signature_name_a = NULL,
signature_id_b = NULL,
signature_name_b = NULL,
omic_signature_a = NULL,
omic_signature_b = NULL,
feature_col = "feature_name",
plot = FALSE,
label_a = NULL,
label_b = NULL,
verbose = TRUE,
...
)Arguments
- conn_handler
An R object obtained from
SigRepo::newConnHandler(). Required unlessomic_signature_aandomic_signature_bare supplied.- signature_id_a
Database ID for signature A.
- signature_name_a
Name for signature A.
- signature_id_b
Database ID for signature B.
- signature_name_b
Name for signature B.
- omic_signature_a
Optional OmicSignature R6 object for signature A.
- omic_signature_b
Optional OmicSignature R6 object for signature B.
- feature_col
Column containing feature names. Defaults to
"feature_name".- plot
Logical; whether to draw a simple Venn diagram. Defaults to
FALSE.- label_a
Label for signature A in the plot and output table.
- label_b
Label for signature B in the plot and output table.
- verbose
Logical; whether or not to print diagnostic messages while retrieving signatures. Defaults to
TRUE.- ...
Additional arguments passed to
plotSignatureOverlap()whenplot = TRUE.