Search for an organism in the database, can handle a singular organism or list
Examples
if (FALSE) { # \dontrun{
# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
dbname = "sigrepo",
host = "sigrepo.org",
port = 3306,
user = "your_username",
password = "your_password"
)
# Search for a list of organims in the database
SigRepo::searchOrganism(
conn_handler = conn_handler,
organism = "Mus musculus",
verbose = TRUE
)
} # }