Search for a list of proteomics features in the database
Usage
searchProteomicsFeatureSet(
conn_handler = NULL,
feature_name = NULL,
organism = NULL,
verbose = TRUE
)Arguments
- conn_handler
An R object obtained from SigRepo::newConnhandler() (required)
- feature_name
A list of feature names to look up. Defaults to 'NULL', which will return all of the feature names in the database.
- organism
A list of organism to look up. Default to 'NULL' which will return all of the organisms in the database.
- verbose
Logical; whether or not to print the diagnostic messages. Defaults to 'TRUE'.
Examples
if (FALSE) { # \dontrun{
# Create a connection handler
conn_handler <- SigRepo::newConnHandler(
dbname = "sigrepo",
host = "sigrepo.org",
port = 3306,
user = "your_username",
password = "your_password"
)
# Search for a list of proteomics features in the database
SigRepo::searchProteomicsFeatureSet(
conn_handler = conn_handler,
feature_name = "test_feature",
organism = "Homo sapiens"
)
} # }